@@ -88,8 +88,9 @@ Key keys[] = {
 	{ MOD, '9',       { focusn,         { "9" }                     } },
 	{ MOD, 'q',       { quit,           { NULL }                    } },
 	{ MOD, 'G',       { escapekey,      { NULL }                    } },
-	{ MOD, 'L',       { redraw,         { NULL }                    } },
+	{ MOD, 'r',       { redraw,         { NULL }                    } },
 	{ MOD, 'X',       { lock,           { NULL }                    } },
+	{ MOD, 'B',       { togglebell,     { NULL }                    } },
 	{ MOD, KEY_PPAGE, { scrollback,     { "-1" }                    } },
 	{ MOD, KEY_NPAGE, { scrollback,     { "1"  }                    } },
 	{ MOD, '?',       { create,         { "man dvtm", "dvtm help" } } },
