@@ -38,7 +38,7 @@
 # include <pty.h>
 #elif defined(__FreeBSD__)
 # include <libutil.h>
-#elif defined(__OpenBSD__) || defined(__NetBSD__)
+#elif defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__)
 # include <util.h>
 #endif
 #ifdef __CYGWIN__
@@ -100,6 +100,7 @@ struct madtty_t {
     unsigned graphmode  : 1;
     unsigned curshid    : 1;
     unsigned curskeymode: 1;
+    unsigned bell       : 1;
 
     /* geometry */
     int rows, cols;
@@ -767,7 +768,9 @@ static void madtty_process_nonprinting(madtty_t *t, wchar_t wc)
         break;
 
       case C0_BEL:
-        /* do nothing for now... maybe a visual bell would be nice? */
+        /* maybe a visual bell would be nice? */
+        if(t->bell)
+            beep();
         break;
 
       case C0_BS:
@@ -1184,6 +1187,16 @@ void madtty_noscroll(madtty_t *t)
 	madtty_scroll(t, t->scroll_amount);
 }
 
+void madtty_bell(madtty_t *t, bool bell)
+{
+    t->bell = bell;
+}
+
+void madtty_togglebell(madtty_t *t)
+{
+    t->bell = !t->bell;
+}
+
 /******************************************************/
 
 pid_t madtty_forkpty(madtty_t *t, const char *p, const char *argv[], const char *env[], int *pty)
